
Tools
=================

**Several tools for manipulation of BeForRecord and BeForEpochs data**

BeForRecord functions
---------------------

.. autosummary::

   befordata.scale_record
   befordata.concat_records
   befordata.detect_sessions
   befordata.split_sessions
   befordata.extract_epochs

.. autofunction:: befordata.scale_record

.. autofunction:: befordata.concat_records

.. autofunction:: befordata.detect_sessions

.. autofunction:: befordata.split_sessions

.. autofunction:: befordata.extract_epochs



BeForEpochs functions
---------------------

.. autosummary::

   befordata.scale_epochs
   befordata.concat_epochs
   befordata.adjust_baseline




.. autofunction:: befordata.scale_epochs

.. autofunction:: befordata.concat_epochs

.. autofunction:: befordata.adjust_baseline
